@@ -1,6 +1,8 @@
 import argparse
+import tempfile
 from contextlib import contextmanager
 
+from gtdbtk.biolib_lite.custom_help_formatter import ChangeTempAction
 from gtdbtk.biolib_lite.custom_help_formatter import CustomHelpFormatter
 from gtdbtk.config.config import AF_THRESHOLD
 
@@ -24,6 +26,11 @@ def arg_group(parser, name):
     yield parser.add_argument_group(name)
 
 
+def __temp_dir(group):
+    group.add_argument('--tmpdir', action=ChangeTempAction, default=tempfile.gettempdir(),
+                       help="specify alternative directory for temporary files")
+
+
 def __genome_dir(group):
     group.add_argument('--genome_dir', help="directory containing genome files in FASTA format")
 
@@ -136,7 +143,8 @@ def __gtdbtk_classification_file(group):
 def __custom_taxonomy_file(group):
     group.add_argument('--custom_taxonomy_file', type=str, default=None,
                        help="file indicating custom taxonomy strings for user "
-                            "genomes, that should contain any genomes belonging to the outgroup")
+                            "genomes, that should contain any genomes belonging to the outgroup. "
+                            "Format: GENOME_ID<TAB>d__;p__;c__;o__;f__;g__;s__")
 
 
 def __prefix(group):
@@ -320,6 +328,7 @@ def get_main_parser():
             __prefix(grp)
             __cpus(grp)
             __force(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -338,9 +347,10 @@ def get_main_parser():
             __pplacer_cpus(grp)
             __force(grp)
             __scratch_dir(grp)
-            __recalculate_red(grp)
+            # __recalculate_red(grp)
             # __split_tree(grp)
             __min_af(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -357,6 +367,7 @@ def get_main_parser():
             __cpus(grp)
             __force(grp)
             __write_single_copy_genes(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -376,6 +387,7 @@ def get_main_parser():
             __rnd_seed(grp)
             __prefix(grp)
             __cpus(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
         with mutex_group(parser, required=False) as grp:
@@ -393,6 +405,7 @@ def get_main_parser():
             __gamma(grp)
             __prefix(grp)
             __cpus(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -411,8 +424,9 @@ def get_main_parser():
             __pplacer_cpus(grp)
             __scratch_dir(grp)
             # __split_tree(grp)
-            __recalculate_red(grp)
+            # __recalculate_red(grp)
             __min_af(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -425,6 +439,7 @@ def get_main_parser():
         with arg_group(parser, 'optional arguments') as grp:
             __gtdbtk_classification_file(grp)
             __custom_taxonomy_file(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -436,6 +451,7 @@ def get_main_parser():
         with arg_group(parser, 'optional arguments') as grp:
             __gtdbtk_classification_file(grp)
             __custom_taxonomy_file(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -446,6 +462,7 @@ def get_main_parser():
             __ingroup_taxon(grp, required=True)
             __output_tree(grp, required=True)
         with arg_group(parser, 'optional arguments') as grp:
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
@@ -469,6 +486,7 @@ def get_main_parser():
             __extension(grp)
             __prefix(grp)
             __cpus(grp)
+            __temp_dir(grp)
             __debug(grp)
             __help(grp)
 
